@@ -1,7 +1,7 @@
 #
 # This file is part of App-Cme
 #
-# This software is Copyright (c) 2016 by Dominique Dumont.
+# This software is Copyright (c) 2017 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,12 +10,12 @@
 #ABSTRACT: Common methods for App::Cme
 
 package App::Cme::Common;
-$App::Cme::Common::VERSION = '1.016';
+$App::Cme::Common::VERSION = '1.024';
 use strict;
 use warnings;
 use 5.10.1;
 
-use Config::Model 2.089;
+use Config::Model 2.103;
 use Config::Model::Lister;
 use Pod::POM;
 use Pod::POM::View::Text;
@@ -23,6 +23,8 @@ use Scalar::Util qw/blessed/;
 use Path::Tiny;
 use Encode qw(decode_utf8);
 
+my @store;
+
 sub cme_global_options {
   my ( $class, $app ) = @_;
 
@@ -30,13 +32,15 @@ sub cme_global_options {
       [ "model-dir=s"        => "Specify an alternate directory to find model files"],
       [ "try-app-as-model!"  => "try to load a model using directly the application name "
                               . "specified as 3rd parameter on the command line"],
-      [ "dev!"               => "test a model under development"],
-      [ "force-load!"        => "Load file even if error are found in data. Bad data are discarded"],
+      [ "save!"              => "Force a save even if no change was done" ],
+      [ "force-load!"        => "Load file even if error are found in data. Bad data are discarded (imply save)"],
       [ "create!"            => "start from scratch."],
       [ "root-dir=s"         => "Change root directory. Mostly used for test"],
       [ "file=s"             => "Specify a target file"],
+      # to be deprecated
       [ "backend=s"          => "Specify a read/write backend"],
       [ "trace|stack-trace!" => "Provides a full stack trace when exiting on error"],
+      [ "verbose=s"         => "Verbosity level (1, 2, 3  or info, debug, trace)"],
       # no bundling
       { getopt_conf => [ qw/no_bundling/ ] }
   );
@@ -46,6 +50,14 @@ sub cme_global_options {
   );
 }
 
+sub check_unknown_args {
+    my ($self, $args) = @_;
+
+    my @unknown_options = grep { /^-/ } @$args ;
+    # $self->usage_error("Unknown option: @unknown_options") if @unknown_options;
+    warn("Unknown option: @unknown_options. Unknown option will soon be a fatal error.") if @unknown_options;
+}
+
 # modifies $args in place
 sub process_args {
     my ($self, $opt, $args) = @_;
@@ -70,19 +82,13 @@ sub process_args {
 
     say "cme: using $root_model model" unless $opt->{quiet};
 
-    if ($opt->{dev}) {
-        # ignore $dev if run as root
-        if ( $> ) {
-            unshift @INC, 'lib';
-            $opt->{model_dir} = 'lib/Config/Model/models/';
-        }
-        else {
-            warn "-dev option is ignored when run as root\n";
-        }
-    }
-
     my $command = (split('::', ref($self)))[-1] ;
 
+    if ($appli_info->{$application}{require_config_file}
+            and $appli_info->{$application}{require_backend_argument}) {
+        die "Error in $root_model model: cannot have both require_config_file and require_backend_argument.\n";
+    }
+
     # @ARGV should be [ $config_file ] [ modification_instructions ]
     my $config_file;
     if ( $appli_info->{$application}{require_config_file} ) {
@@ -95,6 +101,17 @@ sub process_args {
         $config_file = $opt->{file};
     }
 
+    if ( $appli_info->{$application}{require_backend_argument} ) {
+        # let the backend handle a missing arg and provide a clear error message
+        my $b_arg = $opt->{_backend_arg} = shift @$args ;
+        if (not $b_arg) {
+            my $message = $appli_info->{$application}{backend_argument_info} ;
+            my $insert = $message ? " ( $message )": '';
+            die "application $application requires a 3rd argument$insert. "
+                . "I.e. 'cme $command $application <backend_arg>'\n";
+        }
+    }
+
     # remove legacy '~~'
     if ($args->[0] and $args->[0] eq '~~') {
         warn "Argument '~~' was a bad idea and is now ignored. Use -file option to "
@@ -114,8 +131,32 @@ sub process_args {
 sub model {
     my ($self, $opt, $args) = @_;
 
-    return $self->{_model}
-        ||= Config::Model->new( model_dir => $opt->{model_dir} );
+    my @levels = qw/WARN INFO DEBUG TRACE/;
+    my $optv = $opt->{verbose} ;
+
+    my $log_level;
+    if (defined $optv) {
+        if ($optv =~ /^\d$/) {
+            $log_level =  $levels[$opt->{verbose}];
+        }
+        else {
+            ($log_level) = grep { /^$optv/i } @levels;
+        }
+        if (not $log_level) {
+            die "unknown log level $optv. Must be 1 ,2, 3 or warn, info, debug, trace.\n" ;
+        }
+    }
+
+
+    my %cm_args;
+    $cm_args{model_dir} = $opt->{model_dir} if $opt->{model_dir};
+    $cm_args{log_level} = $log_level if $log_level;
+
+    if (not $self->{_model}) {
+        my $model = $self->{_model} = Config::Model->new( %cm_args );
+        push @store, $model;
+    }
+    return $self->{_model};
 }
 
 sub instance {
@@ -131,6 +172,7 @@ sub instance {
             check           => $opt->{force_load} ? 'no' : 'yes',
             auto_create     => $opt->{create},
             backend         => $opt->{backend},
+            backend_arg     => $opt->{_backend_arg},
             backup          => $opt->{backup},
             config_file     => $opt->{_config_file},
             config_dir      => $opt->{_config_dir},
@@ -228,7 +270,7 @@ App::Cme::Common - Common methods for App::Cme
 
 =head1 VERSION
 
-version 1.016
+version 1.024
 
 =head1 SYNOPSIS
 
@@ -244,7 +286,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Dominique Dumont.
+This software is Copyright (c) 2017 by Dominique Dumont.
 
 This is free software, licensed under:
 
